@@ -99,7 +99,7 @@ nsIPCService::~nsIPCService()
 // --------------------------------------------------------------------------
 //
 
-NS_IMPL_THREADSAFE_ISUPPORTS2(nsIPCService, nsIIPCService, nsIObserver);
+NS_IMPL_THREADSAFE_ISUPPORTS2(nsIPCService, nsIIPCService, nsIObserver)
 
 NS_METHOD
 nsIPCService::Init()
@@ -669,7 +669,7 @@ nsIPCService::Observe(nsISupports *aSubject, const char *aTopic,
 // nsIPCRequest implementation
 
 // nsISupports implementation
-NS_IMPL_THREADSAFE_ISUPPORTS1 (nsIPCRequest, nsIIPCRequest);
+NS_IMPL_THREADSAFE_ISUPPORTS1 (nsIPCRequest, nsIIPCRequest)
 
 
 // nsIPCRequest implementation
