@@ -168,7 +168,7 @@ NS_IMPL_THREADSAFE_ISUPPORTS5(nsPipeChannel,
                               nsIChannel, 
                               nsIRequest,
                               nsIStreamListener,
-                              nsIPipeTransportHeaders); 
+                              nsIPipeTransportHeaders)
 
 ///////////////////////////////////////////////////////////////////////////////
 // nsIPipeChannel methods
