@@ -161,7 +161,7 @@ NS_IMPL_THREADSAFE_ISUPPORTS8(nsPipeTransport,
                               nsIOutputStream,
                               nsIStreamListener,
                               nsIInputStreamCallback,
-                              nsIOutputStreamCallback);
+                              nsIOutputStreamCallback)
 #else // !MOZILLA_VERSION
 // Mods for Mozilla version prior to 1.3b
 NS_IMPL_THREADSAFE_ISUPPORTS8(nsPipeTransport, 
@@ -172,7 +172,7 @@ NS_IMPL_THREADSAFE_ISUPPORTS8(nsPipeTransport,
                               nsIOutputStream,
                               nsIStreamListener,
                               nsIInputStreamObserver,
-                              nsIOutputStreamObserver);
+                              nsIOutputStreamObserver)
 #endif // !MOZILLA_VERSION
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1713,7 +1713,7 @@ nsPipeTransport::StopRequest(nsresult aStatus)
 // nsISupports implementation
 NS_IMPL_THREADSAFE_ISUPPORTS2 (nsStdoutPoller,
                                nsIPipeTransportPoller,
-                               nsIRunnable);
+                               nsIRunnable)
 
 
 // nsStdoutPoller implementation
@@ -2393,7 +2393,7 @@ nsStdoutPoller::Run()
 // nsISupports implementation
 NS_IMPL_THREADSAFE_ISUPPORTS2 (nsStdinWriter,
                                nsIPipeTransportWriter,
-                               nsIRunnable);
+                               nsIRunnable)
 
 
 // nsStdinWriter implementation
